import { PrismaClient } from '@prisma/client';
import bcrypt from 'bcryptjs';
import jwt from 'jsonwebtoken';
import { User } from '../../src/types/auth.js';

const prisma = new PrismaClient();

export const authService = {
  login: async (email: string, password: string) => {
    const user = await prisma.user.findUnique({
      where: { email },
      select: {
        id: true,
        email: true,
        password: true,
        displayName: true,
        permissions: true
      }
    });

    if (!user || !await bcrypt.compare(password, user.password)) {
      throw new Error('Invalid credentials');
    }

    const token = await authService.generateToken(user.id);
    const { password: _, ...userWithoutPassword } = user;
    
    return {
      user: userWithoutPassword as User,
      token
    };
  },

  generateToken: async (userId: string) => {
    return jwt.sign(
      { id: userId },
      process.env.JWT_SECRET || '',
      { expiresIn: '24h' }
    );
  },

  createUser: async (userData: {
    email: string;
    password: string;
    displayName: string;
    permissions: any;
  }) => {
    const hashedPassword = await bcrypt.hash(userData.password, 10);
    
    const user = await prisma.user.create({
      data: {
        ...userData,
        password: hashedPassword
      },
      select: {
        id: true,
        email: true,
        displayName: true,
        permissions: true
      }
    });

    return user as User;
  }
};